referencing: JSON Referencing + Python
======================================

Description
-----------

JSON Referencing + Python

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/referencing/

